
	###beer example for split half resampling to find reliable and reproducible components.
rm(list=ls())
gc()

library(ExPosition)
library(gplots)

data(beer.tasting.notes)

##This function is stolen from here: http://lamages.blogspot.com/2013/04/how-to-change-alpha-value-of-colours-in.html
##With some slight modifcations.
add.alpha <- function(col, alpha=0.65){
	apply(
		sapply(col, col2rgb)/255, 
		2, 
		function(x){
			rgb(x[1], x[2], x[3], alpha=alpha)
		}
	)  
}


##data
DAT <- beer.tasting.notes$data
DES <- beer.tasting.notes$pale.sour.style 
beer.cols <- createColorVectorsByDesign(DES)

pca.res <- epPCA(DAT,T,T,DES,F,graphs=F)
epGraphs(pca.res,contributionPlots=F,correlationPlotter=F)

n.iters <- 500
split.1 <- split.2 <- array(NA, dim=c(nrow(pca.res$ExPosition.Data$fj),ncol(pca.res$ExPosition.Data$fj), n.iters))
split.cors <- array(NA,dim=c(nrow(pca.res$ExPosition.Data$fj),nrow(pca.res$ExPosition.Data$fj),n.iters))
for(i in 1:n.iters){
	
	obs <- 1:nrow(DAT)	
	s1.indices <- sample(obs,round(nrow(DAT)/2))
	s2.indices <- obs[which(!(obs %in% s1.indices))]
	
	s1.res <- epPCA(DAT[s1.indices,],T,T,graphs=F)
	s2.res <- epPCA(DAT[s2.indices,],T,T,graphs=F)
	
	split.1[,1:min(ncol(s1.res$ExPosition.Data$fj),ncol(pca.res$ExPosition.Data$fj)),i] <- s1.res$ExPosition.Data$fj[,1:min(ncol(s1.res$ExPosition.Data$fj),ncol(pca.res$ExPosition.Data$fj))]
	split.2[,1:min(ncol(s2.res$ExPosition.Data$fj),ncol(pca.res$ExPosition.Data$fj)),i] <- s2.res$ExPosition.Data$fj[,1:min(ncol(s2.res$ExPosition.Data$fj),ncol(pca.res$ExPosition.Data$fj))]
	
	split.cors[,,i] <- cor(split.1[,,i],split.2[,,i])
	
		print(i)
	
}


reliable.comps <- apply(abs(split.cors),c(1,2),mean,na.rm=T)

###which are reliable components?
heatramp <- colorRampPalette(c("mediumorchid2","grey80","palegreen3"))

dev.new()
heatmap.2(reliable.comps,Rowv=FALSE,Colv=NA,trace="none",dendrogram="none",density.info="none",col=heatramp(64),scale="none",key=T,breaks=seq(0,1,length.out=65))

	##Zoom in!
dev.new()
heatmap.2(reliable.comps[1:6,1:6],Rowv=FALSE,Colv=NA,cellnote=round(reliable.comps[1:6,1:6],digits=2),trace="none",dendrogram="none",density.info="none",col=heatramp(64),scale="none", notecol="white",key=T,breaks=seq(0,1,length.out=65))
